@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Draw SVG maps"""
 # This file is part of svgis.
 # https://github.com/fitnr/svgis
@@ -14,7 +13,6 @@ from functools import partial
 import fiona
 import fiona.transform
 from pyproj.crs import CRS
-from six import string_types
 
 from . import bounding, draw, projection
 from . import style as _style
@@ -117,7 +115,7 @@ class SVGIS:
     def __init__(self, files, bounds=None, crs=None, **kwargs):
         self.log = logging.getLogger('svgis')
 
-        if isinstance(files, string_types):
+        if isinstance(files, str):
             self.files = [files]
         elif isinstance(files, Iterable):
             self.files = files
@@ -524,7 +522,7 @@ class SVGIS:
             self.log.debug('translating contents to fit')
 
         # Create container and then SVG
-        container = svg.group(members, fill_rule='evenodd', transform=transform_attrib)
+        container = svg.group(members, transform=transform_attrib)
         drawing = svg.drawing(size, [container], style=style, precision=precision, viewbox=viewbox)
 
         if kwargs.pop('inline', False):
