@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # This file is part of svgis.
 # https://github.com/fitnr/svgis
 # Licensed under the GNU General Public License v3 (GPLv3) license:
@@ -12,13 +10,6 @@ from svgis.errors import SvgisError
 
 
 class UtilsTestCase(unittest.TestCase):
-    def testPosInt(self):
-        with self.assertRaises(SvgisError):
-            utils.posint(-1)
-        self.assertEqual(utils.posint(1), 1)
-        self.assertEqual(utils.posint(111), 111)
-        self.assertEqual(utils.posint(1.11), 1)
-
     def test_isinf(self):
         self.assertTrue(utils.isinf(float('inf')))
         self.assertTrue(utils.isinf(float('-inf')))
